@@ -19,11 +19,16 @@ struct sandbox_info_t {
 	char sandbox_lib[SB_PATH_MAX];
 	char sandbox_rc[SB_PATH_MAX];
 	char work_dir[SB_PATH_MAX];
-	char var_tmp_dir[SB_PATH_MAX];
 	char tmp_dir[SB_PATH_MAX];
 	char *home_dir;
-} sandbox_info_t;
+};
 
 extern char **setup_environ(struct sandbox_info_t *sandbox_info, bool interactive);
 
+#define sb_warn(fmt, args...)  fprintf(stderr, "%s:%s  " fmt "\n", "sandbox", __func__, ## args)
+#define sb_pwarn(fmt, args...) sb_warn(fmt ": %s\n", ## args, strerror(errno))
+#define _sb_err(func, fmt, args...) do { sb_##func(fmt, ## args); exit(EXIT_FAILURE); } while (0)
+#define sb_err(fmt, args...)  _sb_err(warn, fmt, ## args)
+#define sb_perr(fmt, args...) _sb_err(pwarn, fmt, ## args)
+
 #endif
